@@ -1,19 +1,24 @@
-# fields is a package for analysis of spatial data written for
-  # the R software environment .
-  # Copyright (C) 2018
-  # University Corporation for Atmospheric Research (UCAR)
-  # Contact: Douglas Nychka, nychka@ucar.edu,
-  # National Center for Atmospheric Research,
-  # PO Box 3000, Boulder, CO 80307-3000
-  #
-  # This program is free software; you can redistribute it and/or modify
-  # it under the terms of the GNU General Public License as published by
-  # the Free Software Foundation; either version 2 of the License, or
-  # (at your option) any later version.
-  # This program is distributed in the hope that it will be useful,
-  # but WITHOUT ANY WARRANTY; without even the implied warranty of
-  # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-  # GNU General Public License for more details.
+#
+# fields  is a package for analysis of spatial data written for
+# the R software environment.
+# Copyright (C) 2021 Colorado School of Mines
+# 1500 Illinois St., Golden, CO 80401
+# Contact: Douglas Nychka,  douglasnychka@gmail.edu,
+#
+# This program is free software; you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation; either version 2 of the License, or
+# (at your option) any later version.
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with the R software environment if not, write to the Free Software
+# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+# or see http://www.r-project.org/Licenses/GPL-2
+##END HEADER
 
 suppressMessages(library(fields))
 #
@@ -97,9 +102,9 @@ test.for.zero( hold, hold4, tag="predict for null drift " )
 tps.fit<-Tps( x,y, scale.type="unscaled", Z= Zcov)
 
 # here is lazy way to get a grid.list
-   fields.x.to.grid( x, nx=20,ny=20)-> gridlist
+   gridList<- fields.x.to.grid( x, nx=20,ny=20)
 
-   xg<- make.surface.grid(gridlist)
+   xg<- make.surface.grid(gridList)
    Zcov.grid<- xg[,1]**3 + xg[,2]**3
 
 ########### tests on just predict have been commented out to 
@@ -108,11 +113,11 @@ tps.fit<-Tps( x,y, scale.type="unscaled", Z= Zcov)
 ########### future debugging ...
 
 # full surface with covariate
-#   curv.mean1 <- predictSurface(tps.fit, grid.list = gridlist, extrap = TRUE,
+#   curv.mean1 <- predictSurface(tps.fit,  gridlist, extrap = TRUE,
 ##        Z =Zcov.grid, drop.Z = FALSE)$z
 
 # just the spline surface
-#   curv.mean2 <- predictSurface(tps.fit, grid.list = gridlist,
+#   curv.mean2 <- predictSurface(tps.fit, gridlist,
 #                   extrap = TRUE,drop.Z=TRUE)$z
 
 # explicitly here is the difference surface of curv.mean1 and curv.mean2
@@ -121,7 +126,7 @@ tps.fit<-Tps( x,y, scale.type="unscaled", Z= Zcov)
 
 ## new tests
 
-   predictSurfaceSE( tps.fit, grid.list=gridlist, extrap=TRUE,
+   predictSurfaceSE( tps.fit, gridList, extrap=TRUE,
                drop.Z=TRUE)$z-> curv.var1
 
    predictSE( tps.fit, xg, drop.Z=TRUE)-> curv.var2
