@@ -1,19 +1,24 @@
- # fields is a package for analysis of spatial data written for
-  # the R software environment .
-  # Copyright (C) 2018
-  # University Corporation for Atmospheric Research (UCAR)
-  # Contact: Douglas Nychka, nychka@ucar.edu,
-  # National Center for Atmospheric Research,
-  # PO Box 3000, Boulder, CO 80307-3000
-  #
-  # This program is free software; you can redistribute it and/or modify
-  # it under the terms of the GNU General Public License as published by
-  # the Free Software Foundation; either version 2 of the License, or
-  # (at your option) any later version.
-  # This program is distributed in the hope that it will be useful,
-  # but WITHOUT ANY WARRANTY; without even the implied warranty of
-  # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-  # GNU General Public License for more details.
+#
+# fields  is a package for analysis of spatial data written for
+# the R software environment.
+# Copyright (C) 2021 Colorado School of Mines
+# 1500 Illinois St., Golden, CO 80401
+# Contact: Douglas Nychka,  douglasnychka@gmail.edu,
+#
+# This program is free software; you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation; either version 2 of the License, or
+# (at your option) any later version.
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with the R software environment if not, write to the Free Software
+# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+# or see http://www.r-project.org/Licenses/GPL-2
+##END HEADER
 
 
 suppressMessages(library(fields))
@@ -216,7 +221,7 @@ ind<- sample( 1:(nx*ny), 600)
 xdat<- xg[ind,]
 ydat <- ztrue[ind]
 out<- fastTps(xdat, ydat, aRange=.3)
-out.p<-predictSurface( out, grid=gl, extrap=TRUE)
+out.p<-predictSurface( out, gridList=gl, extrap=TRUE)
 # perfect agreement at data
 test.for.zero( ydat, c( out.p$z)[ind],tol=5e-7, tag="fastTps interp1")
 #image.plot(x,y,matrix( ztrue, nx,ny)- out.p$z) 
